pub enum ConfirmSource {
Default,
Explicit,
}Expand description
The provenance of a submitted confirmation value.
Variants
Default
The user submitted the configured default without selecting an answer.
Explicit
The user selected an answer with a key before submitting.