InlineResizePolicy

Enum InlineResizePolicy 

pub enum InlineResizePolicy {
    ReturnError,
    ClearViewportAndRedraw,
}
What an inline prompt does when its terminal viewport is resized.

Variants



ReturnError

Stop the form and return RunError::Resized without erasing an unlocatable prompt region.



ClearViewportAndRedraw

Clear the visible primary-buffer viewport and redraw the current form.

This does not enter the alternate screen or clear scrollback, but it does erase every other visible cell in the viewport.