#[non_exhaustive]pub enum RunError {
NotInteractive,
Resized {
cleanup: Option<Error>,
},
Io {
operation: IoOperation,
source: Error,
cleanup: Option<Error>,
},
}Expand description
An error that prevents a form from completing normally.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotInteractive
Standard input and standard error are not both interactive terminals.
Resized
The terminal was resized while an inline prompt configured with
crate::InlineResizePolicy::ReturnError was running.
Io
A runtime operation failed; cleanup is retained separately when it also failed.