pub trait Field: Sealed + 'static { }Expand description
A crate-provided prompt field.
The trait is sealed: applications compose fields supplied by this crate rather than coupling a field implementation to terminal lifecycle details.
pub trait Field: Sealed + 'static { }A crate-provided prompt field.
The trait is sealed: applications compose fields supplied by this crate rather than coupling a field implementation to terminal lifecycle details.